import javax.swing.*;
import java.awt.*;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.awt.event.ComponentAdapter;
import java.awt.event.ComponentEvent;
import java.util.Objects;
import java.util.Random;

public class FormMap extends JFrame{
    private AbstractMap _abstractMap;
    private JPanel mainPanel;
    private JToolBar toolBar;
    private JLabel toolBarLabelSpeed;
    private JLabel toolBarLabelWieght;
    private JLabel toolBarLabelColor;
    private JButton buttonCreate;
    private JButton buttonCreateModif;
    private JButton buttonRight;
    private JButton buttonUp;
    private JButton buttonDown;
    private JButton buttonLeft;
    private JComboBox ComboBoxSelectorMap;
    private JPanel drawPanel;

    public FormMap(){
        InitializeComponent();
        _abstractMap = new SimpleMap();
    }

    private void SetData(DrawingWarship warship){
        Graphics2D graphics = (Graphics2D) drawPanel.getGraphics();
        graphics.clearRect(0, 0, drawPanel.getWidth(), drawPanel.getHeight());
        drawPanel.paintComponents(graphics);
        graphics.drawImage(_abstractMap.CreateMap(drawPanel.getWidth(), drawPanel.getHeight(), new DrawingObjectWarship(warship)),0,0,null);
        toolBarLabelSpeed.setText("Color: " + warship.GetWarship().GetSpeed() + "  ");
        toolBarLabelWieght.setText("Weight: " + warship.GetWarship().GetWeight() + "  ");
        toolBarLabelColor.setText("Color: " + warship.GetWarship().GetBodyColor().getRed() + " " +
                warship.GetWarship().GetBodyColor().getGreen() + " " + warship.GetWarship().GetBodyColor().getBlue());
    }

    private void resizeWindow() {
        _warship.ChangeBorders(drawPanel.getWidth(), drawPanel.getHeight());
        Draw();
    }

    private void InitializeComponent() {
        setContentPane(mainPanel);
        setTitle("Warship");
        setSize(900, 700);
        setDefaultCloseOperation(WindowConstants.EXIT_ON_CLOSE);
        setVisible(true);

        Icon iconUp = new ImageIcon("src\\Images\\ArrowUp.jpg");
        buttonUp.setIcon(iconUp);
        Icon iconDown = new ImageIcon("src\\Images\\ArrowDown.jpg");
        buttonDown.setIcon(iconDown);
        Icon iconLeft = new ImageIcon("src\\Images\\ArrowLeft.jpg");
        buttonLeft.setIcon(iconLeft);
        Icon iconRight = new ImageIcon("src\\Images\\ArrowRight.jpg");
        buttonRight.setIcon(iconRight);

        ComboBoxSelectorMap.addActionListener(new ActionListener() {
            @Override
            public void actionPerformed(ActionEvent e) {
                String mapName = Objects.requireNonNull(ComboBoxSelectorMap.getSelectedItem()).toString();
                switch (mapName){
                    case "Простая карта":
                        _abstractMap = new SimpleMap();
                        break;
                    case "Вторая карта":
                        _abstractMap = new LineMap();
                        break;
                }
            }
        });

        //кнопка добавления объекта
        buttonCreate.addActionListener(new ActionListener() {
            @Override
            public void actionPerformed(ActionEvent e) {
                Random rnd = new Random();
                var warship = new DrawingWarship(rnd.nextInt(100, 300), rnd.nextInt(1000, 2000),
                        new Color(rnd.nextInt(256), rnd.nextInt(256), rnd.nextInt(256)));
                SetData(warship);
                Draw();
            }
        });

        //добавление модифицированного объекта
        /*buttonCreateModif.addActionListener(new ActionListener() {
            @Override
            public void actionPerformed(ActionEvent e) {
                Random rnd = new Random();
                _warship = new DrawingAircraftCarrier(rnd.nextInt(100, 300), rnd.nextInt(1000, 2000),
                        new Color(rnd.nextInt(256), rnd.nextInt(256), rnd.nextInt(256)),
                        new Color(rnd.nextInt(256), rnd.nextInt(256), rnd.nextInt(256)),
                        rnd.nextBoolean(), rnd.nextBoolean(), rnd.nextBoolean());
                SetData();
                Draw();
            }
        });

        buttonLeft.addActionListener(new ActionListener() {
            @Override
            public void actionPerformed(ActionEvent e) {
                if (_warship != null) _warship.MoveTransport(Direction.Left);
                Draw();
            }
        });

        buttonRight.addActionListener(new ActionListener() {
            @Override
            public void actionPerformed(ActionEvent e) {
                if (_warship != null) _warship.MoveTransport(Direction.Right);
                Draw();
            }
        });

        buttonUp.addActionListener(new ActionListener() {
            @Override
            public void actionPerformed(ActionEvent e) {
                if (_warship != null) _warship.MoveTransport(Direction.Up);
                Draw();
            }
        });

        buttonDown.addActionListener(new ActionListener() {
            @Override
            public void actionPerformed(ActionEvent e) {
                if (_warship != null) _warship.MoveTransport(Direction.Down);
                Draw();
            }
        });*/

        mainPanel.addComponentListener(new ComponentAdapter() {
            @Override
            public void componentResized(ComponentEvent e) {
                super.componentResized(e);
                resizeWindow();
            }
        });
    }
}
